# osdu_perf/operations/azure_test_operation/__init__.py
"""Azure Load Test operations for OSDU Performance Testing Framework"""

from .azure_test_runner import AzureLoadTestRunner

__all__ = [
    "AzureLoadTestRunner"
]
